
# craterstats/sample

These files are samples of the different data formats read by Craterstats. 
Normally, these are generated by another software tool, such as CraterTools, 
but if you need to produce data in a different way, you can model the output 
on one of these.
